@@ -87,6 +87,7 @@ var (
 
 	Etag            = flag.Bool("etag", true, "Enable Etag header")
 	UserAgent       = flag.String("useragent", fmt.Sprintf("Cloudflare-%v (+https://github.com/cloudflare/gortr)", AppVersion), "User-Agent header")
+	Mime            = flag.String("mime", "application/json", "Accept setting format (some servers may prefer text/json)")
 	RefreshInterval = flag.Int("refresh", 600, "Refresh interval in seconds")
 	MaxConn         = flag.Int("maxconn", 0, "Max simultaneous connections (0 to disable limit)")
 	SendNotifs      = flag.Bool("notifications", true, "Send notifications to clients")
@@ -94,8 +95,9 @@ var (
 	Slurm        = flag.String("slurm", "", "Slurm configuration file (filters and assertions)")
 	SlurmRefresh = flag.Bool("slurm.refresh", true, "Refresh along the cache")
 
-	LogLevel = flag.String("loglevel", "info", "Log level")
-	Version  = flag.Bool("version", false, "Print version")
+	LogLevel   = flag.String("loglevel", "info", "Log level")
+	LogVerbose = flag.Bool("log.verbose", false, "Additional debug logs")
+	Version    = flag.Bool("version", false, "Print version")
 
 	NumberOfROAs = prometheus.NewGaugeVec(
 		prometheus.GaugeOpts{
@@ -107,7 +109,7 @@ var (
 	LastRefresh = prometheus.NewGaugeVec(
 		prometheus.GaugeOpts{
 			Name: "rpki_refresh",
-			Help: "Last successfull request for the given URL.",
+			Help: "Last successful request for the given URL.",
 		},
 		[]string{"path"},
 	)
@@ -196,7 +198,9 @@ func (s *state) fetchFile(file string) ([]byte, error) {
 		client := &http.Client{Transport: tr}
 		req, err := http.NewRequest("GET", file, nil)
 		req.Header.Set("User-Agent", s.userAgent)
-		req.Header.Set("Accept", "text/json")
+		if s.mime != "" {
+			req.Header.Set("Accept", s.mime)
+		}
 
 		etag, ok := s.etags[file]
 		if s.enableEtags && ok {
@@ -218,7 +222,10 @@ func (s *state) fetchFile(file string) ([]byte, error) {
 		if err != nil {
 			return nil, err
 		}
-
+		if fhttp.Body != nil {
+			defer fhttp.Body.Close()
+		}
+		defer client.CloseIdleConnections()
 		RefreshStatusCode.WithLabelValues(file, fmt.Sprintf("%d", fhttp.StatusCode)).Inc()
 
 		if fhttp.StatusCode == 304 {
@@ -536,6 +543,7 @@ type state struct {
 	lastts        time.Time
 	sendNotifs    bool
 	userAgent     string
+	mime          string
 	etags         map[string]string
 	enableEtags   bool
 	useSerial     int
@@ -635,6 +643,7 @@ func main() {
 		SessId:          *SessionID,
 		KeepDifference:  3,
 		Log:             log.StandardLogger(),
+		LogVerbose:      *LogVerbose,
 
 		RefreshInterval: uint32(*RefreshRTR),
 		RetryInterval:   uint32(*RetryRTR),
@@ -673,6 +682,7 @@ func main() {
 		verify:       *Verify,
 		checktime:    *TimeCheck,
 		userAgent:    *UserAgent,
+		mime:         *Mime,
 		etags:        make(map[string]string),
 		enableEtags:  *Etag,
 		lockJson:     &sync.RWMutex{},
